@@ -1,4 +1,4 @@
-# $Id: PathInfo.pm,v 1.2 2002/02/01 14:45:07 matts Exp $
+# $Id: PathInfo.pm,v 1.3 2002/07/30 10:33:42 jwalt Exp $
 
 package Apache::AxKit::StyleChooser::PathInfo;
 
@@ -41,23 +41,29 @@ Apache::AxKit::StyleChooser::PathInfo - Choose stylesheet using PATH_INFO
 
 =head1 SYNOPSIS
 
-	PerlHandler Apache::AxKit::StyleChooser::PathInfo \
-			AxKit
+  AxAddPlugin Apache::AxKit::StyleChooser::PathInfo
 
 =head1 DESCRIPTION
 
-This module lets you pick a stylesheet based on the extra PATH_INFO. To use
-it, simply add this module to the list of PerlHandlers prior to
-AxKit:
+This module lets you pick a stylesheet based on the extra PATH_INFO. 
+To use it, simply add this module as an AxKit plugin that 
+will be run before main AxKit processing is done.
 
-	PerlHandler Apache::AxKit::StyleChooser::PathInfo \
-			AxKit
+  AxAddPlugin Apache::AxKit::StyleChooser::PathInfo  
 
 Then simply by referencing your xml files as follows:
 
-	http://xml.server.com/myfile.xml/printable
+   http://xml.server.com/myfile.xml/printable
 
 You will recieve the alternate stylesheets with title "printable". See 
 the HTML 4.0 specification for more details on stylesheet choice.
 
+See the B<AxStyleName> AxKit configuration directive
+for more information on how to setup named styles.
+
+=head1 SEE ALSO
+
+AxKit.
+
 =cut
+
